@@ -1,22 +1,15 @@
-/*
- *  File ergm/src/sisfuns.h
- *  Part of the statnet package, http://statnetproject.org
+/*  File networksis/src/sisfuns.h
+ *  Part of the statnet package, http://statnet.org
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) in
- *    http://statnetproject.org/attribution
+ *    http://statnet.org/attribution
  *
- * Copyright 2003 Mark S. Handcock, University of Washington
- *                David R. Hunter, Penn State University
- *                Carter T. Butts, University of California - Irvine
- *                Steven M. Goodreau, University of Washington
- *                Martina Morris, University of Washington
- * Copyright 2007 The statnet Development Team
- */
-#ifndef SIS_H
-#define SIS_H
+ *  Copyright 2012 the statnet development team
+ ************************************************************************/
 
-#include "edgetree.h"
+#ifndef SISFUNS_H
+#define SISFUNS_H
 
 void sisconj (int *colsums, int *conjseq, int nrow, int ncol, int i);
 void sissort(int *rowsums, int *order, int nrow);
